# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

DMRI_MERGEPATHS_METADATA = Metadata(
    id="a806a559aa7a4e196c0f4f692e84bf6c75a34049.boutiques",
    name="dmri_mergepaths",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


DmriMergepathsParameters = typing.TypedDict('DmriMergepathsParameters', {
    "__STYX_TYPE__": typing.Literal["dmri_mergepaths"],
    "input_volumes": list[InputPathType],
    "input_directory": typing.NotRequired[str | None],
    "output_volume": str,
    "color_table": InputPathType,
    "threshold": float,
    "debug": bool,
    "check_opts": bool,
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "dmri_mergepaths": dmri_mergepaths_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
    }.get(t)


class DmriMergepathsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dmri_mergepaths(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def dmri_mergepaths_params(
    input_volumes: list[InputPathType],
    output_volume: str,
    color_table: InputPathType,
    threshold: float,
    input_directory: str | None = None,
    debug: bool = False,
    check_opts: bool = False,
) -> DmriMergepathsParameters:
    """
    Build parameters.
    
    Args:
        input_volumes: Input volume(s).
        output_volume: Output volume.
        color_table: Color table file.
        threshold: Lower threshold for display (0<=num<=1, as fraction of max).
        input_directory: Input directory (optional). If specified, names of\
            input files are relative to this.
        debug: Turn on debugging.
        check_opts: Don't run anything, just check options and exit.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "dmri_mergepaths",
        "input_volumes": input_volumes,
        "output_volume": output_volume,
        "color_table": color_table,
        "threshold": threshold,
        "debug": debug,
        "check_opts": check_opts,
    }
    if input_directory is not None:
        params["input_directory"] = input_directory
    return params


def dmri_mergepaths_cargs(
    params: DmriMergepathsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("dmri_mergepaths")
    cargs.extend([execution.input_file(f) for f in params.get("input_volumes")])
    if params.get("input_directory") is not None:
        cargs.extend([
            "--indir",
            params.get("input_directory")
        ])
    cargs.extend([
        "--out",
        params.get("output_volume")
    ])
    cargs.extend([
        "--ctab",
        execution.input_file(params.get("color_table"))
    ])
    cargs.extend([
        "--thresh",
        str(params.get("threshold"))
    ])
    if params.get("debug"):
        cargs.append("--debug")
    if params.get("check_opts"):
        cargs.append("--checkopts")
    return cargs


def dmri_mergepaths_outputs(
    params: DmriMergepathsParameters,
    execution: Execution,
) -> DmriMergepathsOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = DmriMergepathsOutputs(
        root=execution.output_file("."),
    )
    return ret


def dmri_mergepaths_execute(
    params: DmriMergepathsParameters,
    execution: Execution,
) -> DmriMergepathsOutputs:
    """
    A tool for merging diffusion MRI path data.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `DmriMergepathsOutputs`).
    """
    params = execution.params(params)
    cargs = dmri_mergepaths_cargs(params, execution)
    ret = dmri_mergepaths_outputs(params, execution)
    execution.run(cargs)
    return ret


def dmri_mergepaths(
    input_volumes: list[InputPathType],
    output_volume: str,
    color_table: InputPathType,
    threshold: float,
    input_directory: str | None = None,
    debug: bool = False,
    check_opts: bool = False,
    runner: Runner | None = None,
) -> DmriMergepathsOutputs:
    """
    A tool for merging diffusion MRI path data.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volumes: Input volume(s).
        output_volume: Output volume.
        color_table: Color table file.
        threshold: Lower threshold for display (0<=num<=1, as fraction of max).
        input_directory: Input directory (optional). If specified, names of\
            input files are relative to this.
        debug: Turn on debugging.
        check_opts: Don't run anything, just check options and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DmriMergepathsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DMRI_MERGEPATHS_METADATA)
    params = dmri_mergepaths_params(
        input_volumes=input_volumes,
        input_directory=input_directory,
        output_volume=output_volume,
        color_table=color_table,
        threshold=threshold,
        debug=debug,
        check_opts=check_opts,
    )
    return dmri_mergepaths_execute(params, execution)


__all__ = [
    "DMRI_MERGEPATHS_METADATA",
    "DmriMergepathsOutputs",
    "DmriMergepathsParameters",
    "dmri_mergepaths",
    "dmri_mergepaths_params",
]
