# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

MRIS_CA_LABEL_METADATA = Metadata(
    id="c1ae5127f6f6b5ab0ae06b72523899f5770f008a.boutiques",
    name="mris_ca_label",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


MrisCaLabelParameters = typing.TypedDict('MrisCaLabelParameters', {
    "__STYX_TYPE__": typing.Literal["mris_ca_label"],
    "subject": str,
    "hemi": str,
    "canonsurf": InputPathType,
    "classifier": InputPathType,
    "outputfile": str,
    "seed": typing.NotRequired[float | None],
    "sdir": typing.NotRequired[str | None],
    "orig": typing.NotRequired[str | None],
    "long_flag": bool,
    "r": typing.NotRequired[InputPathType | None],
    "novar_flag": bool,
    "nbrs": typing.NotRequired[float | None],
    "f": typing.NotRequired[float | None],
    "t": typing.NotRequired[InputPathType | None],
    "p": typing.NotRequired[str | None],
    "v": typing.NotRequired[float | None],
    "w": typing.NotRequired[str | None],
    "help_flag": bool,
    "version_flag": bool,
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "mris_ca_label": mris_ca_label_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "mris_ca_label": mris_ca_label_outputs,
    }.get(t)


class MrisCaLabelOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_ca_label(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    labeled_surface: OutputPathType
    """Labeled cortical surface model"""


def mris_ca_label_params(
    subject: str,
    hemi: str,
    canonsurf: InputPathType,
    classifier: InputPathType,
    outputfile: str,
    seed: float | None = None,
    sdir: str | None = None,
    orig: str | None = None,
    long_flag: bool = False,
    r: InputPathType | None = None,
    novar_flag: bool = False,
    nbrs: float | None = None,
    f: float | None = None,
    t: InputPathType | None = None,
    p: str | None = None,
    v: float | None = None,
    w: str | None = None,
    help_flag: bool = False,
    version_flag: bool = False,
) -> MrisCaLabelParameters:
    """
    Build parameters.
    
    Args:
        subject: Subject ID for labeling.
        hemi: Hemisphere (rh or lh).
        canonsurf: Name of the spherical surface file that describes the\
            registration of a subject's vertices to the average surface.
        classifier: Specify classifier array input file.
        outputfile: Output annotated surface file listing the region label for\
            each vertex.
        seed: Specify the seed for the random number generator.
        sdir: Specify a subjects directory (default=$SUBJECTS_DIR).
        orig: Specify filename of original surface (default=smoothwm).
        long_flag: Refines the initial labeling read-in from -r (default:\
            disabled).
        r: File containing precomputed parcellation.
        novar_flag: Sets all covariance matrices to the identity (default:\
            disabled).
        nbrs: Neighborhood size (default=2).
        f: Applies mode filter <number> times before writing output\
            (default=10).
        t: Specify parcellation table input file (default: none).
        p: Output file containing label probability for each vertex.
        v: Diagnostic level (default=0).
        w: Writes-out snapshots of gibbs process every <number> iterations to\
            <filename> (default=disabled).
        help_flag: Print help information.
        version_flag: Print version information.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "mris_ca_label",
        "subject": subject,
        "hemi": hemi,
        "canonsurf": canonsurf,
        "classifier": classifier,
        "outputfile": outputfile,
        "long_flag": long_flag,
        "novar_flag": novar_flag,
        "help_flag": help_flag,
        "version_flag": version_flag,
    }
    if seed is not None:
        params["seed"] = seed
    if sdir is not None:
        params["sdir"] = sdir
    if orig is not None:
        params["orig"] = orig
    if r is not None:
        params["r"] = r
    if nbrs is not None:
        params["nbrs"] = nbrs
    if f is not None:
        params["f"] = f
    if t is not None:
        params["t"] = t
    if p is not None:
        params["p"] = p
    if v is not None:
        params["v"] = v
    if w is not None:
        params["w"] = w
    return params


def mris_ca_label_cargs(
    params: MrisCaLabelParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("mris_ca_label")
    cargs.append(params.get("subject"))
    cargs.append(params.get("hemi"))
    cargs.append(execution.input_file(params.get("canonsurf")))
    cargs.append(execution.input_file(params.get("classifier")))
    cargs.append(params.get("outputfile"))
    if params.get("seed") is not None:
        cargs.extend([
            "-seed",
            str(params.get("seed"))
        ])
    if params.get("sdir") is not None:
        cargs.extend([
            "-sdir",
            params.get("sdir")
        ])
    if params.get("orig") is not None:
        cargs.extend([
            "-orig",
            params.get("orig")
        ])
    if params.get("long_flag"):
        cargs.append("-long")
    if params.get("r") is not None:
        cargs.extend([
            "-r",
            execution.input_file(params.get("r"))
        ])
    if params.get("novar_flag"):
        cargs.append("-novar")
    if params.get("nbrs") is not None:
        cargs.extend([
            "-nbrs",
            str(params.get("nbrs"))
        ])
    if params.get("f") is not None:
        cargs.extend([
            "-f",
            str(params.get("f"))
        ])
    if params.get("t") is not None:
        cargs.extend([
            "-t",
            execution.input_file(params.get("t"))
        ])
    if params.get("p") is not None:
        cargs.extend([
            "-p",
            params.get("p")
        ])
    if params.get("v") is not None:
        cargs.extend([
            "-v",
            str(params.get("v"))
        ])
    if params.get("w") is not None:
        cargs.extend([
            "-w",
            params.get("w")
        ])
    if params.get("help_flag"):
        cargs.append("--help")
    if params.get("version_flag"):
        cargs.append("--version")
    return cargs


def mris_ca_label_outputs(
    params: MrisCaLabelParameters,
    execution: Execution,
) -> MrisCaLabelOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = MrisCaLabelOutputs(
        root=execution.output_file("."),
        labeled_surface=execution.output_file(params.get("outputfile")),
    )
    return ret


def mris_ca_label_execute(
    params: MrisCaLabelParameters,
    execution: Execution,
) -> MrisCaLabelOutputs:
    """
    Produces an annotation file in which each cortical surface vertex is assigned a
    neuroanatomical label using a previously-prepared atlas file.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `MrisCaLabelOutputs`).
    """
    params = execution.params(params)
    cargs = mris_ca_label_cargs(params, execution)
    ret = mris_ca_label_outputs(params, execution)
    execution.run(cargs)
    return ret


def mris_ca_label(
    subject: str,
    hemi: str,
    canonsurf: InputPathType,
    classifier: InputPathType,
    outputfile: str,
    seed: float | None = None,
    sdir: str | None = None,
    orig: str | None = None,
    long_flag: bool = False,
    r: InputPathType | None = None,
    novar_flag: bool = False,
    nbrs: float | None = None,
    f: float | None = None,
    t: InputPathType | None = None,
    p: str | None = None,
    v: float | None = None,
    w: str | None = None,
    help_flag: bool = False,
    version_flag: bool = False,
    runner: Runner | None = None,
) -> MrisCaLabelOutputs:
    """
    Produces an annotation file in which each cortical surface vertex is assigned a
    neuroanatomical label using a previously-prepared atlas file.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: Subject ID for labeling.
        hemi: Hemisphere (rh or lh).
        canonsurf: Name of the spherical surface file that describes the\
            registration of a subject's vertices to the average surface.
        classifier: Specify classifier array input file.
        outputfile: Output annotated surface file listing the region label for\
            each vertex.
        seed: Specify the seed for the random number generator.
        sdir: Specify a subjects directory (default=$SUBJECTS_DIR).
        orig: Specify filename of original surface (default=smoothwm).
        long_flag: Refines the initial labeling read-in from -r (default:\
            disabled).
        r: File containing precomputed parcellation.
        novar_flag: Sets all covariance matrices to the identity (default:\
            disabled).
        nbrs: Neighborhood size (default=2).
        f: Applies mode filter <number> times before writing output\
            (default=10).
        t: Specify parcellation table input file (default: none).
        p: Output file containing label probability for each vertex.
        v: Diagnostic level (default=0).
        w: Writes-out snapshots of gibbs process every <number> iterations to\
            <filename> (default=disabled).
        help_flag: Print help information.
        version_flag: Print version information.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisCaLabelOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_CA_LABEL_METADATA)
    params = mris_ca_label_params(
        subject=subject,
        hemi=hemi,
        canonsurf=canonsurf,
        classifier=classifier,
        outputfile=outputfile,
        seed=seed,
        sdir=sdir,
        orig=orig,
        long_flag=long_flag,
        r=r,
        novar_flag=novar_flag,
        nbrs=nbrs,
        f=f,
        t=t,
        p=p,
        v=v,
        w=w,
        help_flag=help_flag,
        version_flag=version_flag,
    )
    return mris_ca_label_execute(params, execution)


__all__ = [
    "MRIS_CA_LABEL_METADATA",
    "MrisCaLabelOutputs",
    "MrisCaLabelParameters",
    "mris_ca_label",
    "mris_ca_label_params",
]
