# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

MRIS_TRANSMANTLE_DYSPLASIA_PATHS_METADATA = Metadata(
    id="8ef0c4c13a7437b6d7549718b592c920d9aec6bf.boutiques",
    name="mris_transmantle_dysplasia_paths",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


MrisTransmantleDysplasiaPathsParameters = typing.TypedDict('MrisTransmantleDysplasiaPathsParameters', {
    "__STYX_TYPE__": typing.Literal["mris_transmantle_dysplasia_paths"],
    "surface": InputPathType,
    "aseg_volume": InputPathType,
    "intensity_volume": InputPathType,
    "xform": InputPathType,
    "output_volume": str,
    "filter": typing.NotRequired[list[float] | None],
    "noise_sensitivity": bool,
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "mris_transmantle_dysplasia_paths": mris_transmantle_dysplasia_paths_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "mris_transmantle_dysplasia_paths": mris_transmantle_dysplasia_paths_outputs,
    }.get(t)


class MrisTransmantleDysplasiaPathsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_transmantle_dysplasia_paths(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output volume file"""


def mris_transmantle_dysplasia_paths_params(
    surface: InputPathType,
    aseg_volume: InputPathType,
    intensity_volume: InputPathType,
    xform: InputPathType,
    output_volume: str,
    filter_: list[float] | None = None,
    noise_sensitivity: bool = False,
) -> MrisTransmantleDysplasiaPathsParameters:
    """
    Build parameters.
    
    Args:
        surface: Surface file.
        aseg_volume: ASEG volume file.
        intensity_volume: Intensity volume file.
        xform: Transformation file.
        output_volume: Output volume file.
        filter_: Apply specified filter with low and high values (not\
            implemented yet).
        noise_sensitivity: Noise-sensitivity normalize inverse (default=1).
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "mris_transmantle_dysplasia_paths",
        "surface": surface,
        "aseg_volume": aseg_volume,
        "intensity_volume": intensity_volume,
        "xform": xform,
        "output_volume": output_volume,
        "noise_sensitivity": noise_sensitivity,
    }
    if filter_ is not None:
        params["filter"] = filter_
    return params


def mris_transmantle_dysplasia_paths_cargs(
    params: MrisTransmantleDysplasiaPathsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("mris_transmantle_dysplasia_paths")
    cargs.append(execution.input_file(params.get("surface")))
    cargs.append(execution.input_file(params.get("aseg_volume")))
    cargs.append(execution.input_file(params.get("intensity_volume")))
    cargs.append(execution.input_file(params.get("xform")))
    cargs.append(params.get("output_volume"))
    if params.get("filter") is not None:
        cargs.extend([
            "-f",
            *map(str, params.get("filter"))
        ])
    if params.get("noise_sensitivity"):
        cargs.append("-n")
    return cargs


def mris_transmantle_dysplasia_paths_outputs(
    params: MrisTransmantleDysplasiaPathsParameters,
    execution: Execution,
) -> MrisTransmantleDysplasiaPathsOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = MrisTransmantleDysplasiaPathsOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(params.get("output_volume")),
    )
    return ret


def mris_transmantle_dysplasia_paths_execute(
    params: MrisTransmantleDysplasiaPathsParameters,
    execution: Execution,
) -> MrisTransmantleDysplasiaPathsOutputs:
    """
    Tool for transmantle dysplasia path computation.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `MrisTransmantleDysplasiaPathsOutputs`).
    """
    params = execution.params(params)
    cargs = mris_transmantle_dysplasia_paths_cargs(params, execution)
    ret = mris_transmantle_dysplasia_paths_outputs(params, execution)
    execution.run(cargs)
    return ret


def mris_transmantle_dysplasia_paths(
    surface: InputPathType,
    aseg_volume: InputPathType,
    intensity_volume: InputPathType,
    xform: InputPathType,
    output_volume: str,
    filter_: list[float] | None = None,
    noise_sensitivity: bool = False,
    runner: Runner | None = None,
) -> MrisTransmantleDysplasiaPathsOutputs:
    """
    Tool for transmantle dysplasia path computation.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        surface: Surface file.
        aseg_volume: ASEG volume file.
        intensity_volume: Intensity volume file.
        xform: Transformation file.
        output_volume: Output volume file.
        filter_: Apply specified filter with low and high values (not\
            implemented yet).
        noise_sensitivity: Noise-sensitivity normalize inverse (default=1).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisTransmantleDysplasiaPathsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_TRANSMANTLE_DYSPLASIA_PATHS_METADATA)
    params = mris_transmantle_dysplasia_paths_params(
        surface=surface,
        aseg_volume=aseg_volume,
        intensity_volume=intensity_volume,
        xform=xform,
        output_volume=output_volume,
        filter_=filter_,
        noise_sensitivity=noise_sensitivity,
    )
    return mris_transmantle_dysplasia_paths_execute(params, execution)


__all__ = [
    "MRIS_TRANSMANTLE_DYSPLASIA_PATHS_METADATA",
    "MrisTransmantleDysplasiaPathsOutputs",
    "MrisTransmantleDysplasiaPathsParameters",
    "mris_transmantle_dysplasia_paths",
    "mris_transmantle_dysplasia_paths_params",
]
